@@ -3,7 +3,7 @@ package Acme::CPANAuthors::Japanese;
 use strict;
 use warnings;
 
-our $VERSION = '0.150912';
+our $VERSION = '0.161021';
 
 use Acme::CPANAuthors::Register (
     ABUI      => 'DAISUKE ABUI',
@@ -21,6 +21,7 @@ use Acme::CPANAuthors::Register (
     AJIYOSHI  => 'yoichi ajiyoshi',
     AKIHIRO   => 'Kodai Takahashi',
     AKIHITO   => 'Akihito Takeda',
+    AKIMACHO  => 'Akimasa Kimura',
     AKIRA     => 'Akira Hangai',
     AKITSUO   => 'Hiroaki Otsu',
     AKIYM     => 'Takumi Akiyama',
@@ -56,6 +57,8 @@ use Acme::CPANAuthors::Register (
     CHIBA     => 'Masahiro Chiba',
     CLAIRVY   => 'NAGAYA Shinichiro',
     CLCL      => 'OONO Yoshitaka',
+    CLICKTX   => 'Munenori Sugimura',
+    CODEHEX   => 'Kei Kamikawa',
     COELA     => 'Satoshi Tamaki',
     COHTAN    => 'Kota Sakoda',
     CSIDE     => 'Hiroki Honda',
@@ -73,6 +76,7 @@ use Acme::CPANAuthors::Register (
     DRAWNBOY  => 'Hideaki Tanaka',
     DSYRTM    => 'Mitsuru Yasuda',
     EGAWATA   => 'Takashi Egawa',
+    FIRSTJUN  => 'Jun Ito',
     FNOBI     => 'Fujisawa Shin',
     FUJIMURA  => 'FUJIMURA Yuki',
     FUJISAWA  => 'Mizuki Fujisawa',
@@ -162,17 +166,21 @@ use Acme::CPANAuthors::Register (
     IWAMATSU  => 'Nobuhiro Iwamatsu',
     IWATA     => 'Motonori Iwata',
     JAMADAM   => 'Sugama Keita',
+    JERO      => 'Naoki Yaguchi',
     JIRO      => 'Jiro Nishiguchi',
     JKONDO    => 'Junya Kondo',
     JUDIOO    => 'Udo Oji',
     JUNICHIRO => 'Junichiro Tobe',
     JUNNAMA   => 'Junnama Noda',
     KAKUDRUMS => 'Yoichi Watanabe',
+    KAMIOKA   => 'Nobuhiro Kamioka',
     KAMIPO    => 'Ryuta Kamizono',
     KAMO      => 'Yoshikazu Kamoshida',
     KAORUO    => 'Kaoru Oshita',
+    KAORUOT   => 'Kaoru Oshita',
     KARUPA    => 'Kenta Sato',
     KASHIWABA => 'Nobuyuki Kashiwabara',
+    KATAGIRI  => 'Tomoharu Katagiri',
     KAWABATA  => 'KAWABATA Kazumichi',
     KAWAMURAY => 'Yuto KAWAMURA',
     KAWASAKI  => 'Kawasaki Yusuke',
@@ -182,12 +190,15 @@ use Acme::CPANAuthors::Register (
     KAZUKIMA  => 'Kazuki MATSUDA',
     KAZUNORI  => 'Kazunori Minoda',
     KAZUPH    => 'Kazuhiro Homma',
+    KAZYAM    => 'Kazumasa Yamamoto',
     KEISUKE   => 'Keisuke Kuramata',
     KENJIRO   => 'Kenjiro Hirakawa',
     KENSHIN   => 'Kenshin YAMADA',
     KENTARO   => 'Kentaro Kuribayashi',
+    KESIN     => 'Kenta Kase',
     KEYAMB    => 'YASUTAKE Kiyoshi',
     KFLY      => 'Kenta Kobayashi',
+    KGA       => 'Wataru TOYA',
     KIMATA    => 'Tetsuya KIMATA',
     KIMOTO    => 'Yuki Kimoto',
     KIMURA    => 'Takeshi Kimura',
@@ -337,8 +348,10 @@ use Acme::CPANAuthors::Register (
     NOZZZZZ   => 'Tetsunari Nozaki',
     NTAKANASI => 'Nao Takanashi',
     NTSUTSUMI => 'Naoya Tsutsumi',
+    NUKOSUKE  => 'nuko suke',
     NYAGAO    => 'Takahiro Nagao',
     NYARLA    => 'Naoki Okamura',
+    OCEORA    => 'eisaku ando',
     OGASAWARA => 'leann ogasawara',
     OGATA     => 'OGATA Tetsuji',
     OGAWA     => 'Hirotaka Ogawa',
@@ -381,6 +394,7 @@ use Acme::CPANAuthors::Register (
     SADAHIRO  => 'SADAHIRO Tomoyuki',
     SASAKURE  => 'Kei Shimada (sasakure_kei)',
     SASAO     => 'SASAO Takahiro',
+    SASARON   => 'Katsuhiro Sasaki',
     SASATA    => 'Tatsuya "sasata299" Sasaki',
     SASAZUKA  => 'Seiji Sasazuka',
     SATETSU   => 'shotaro akiyama',
@@ -406,8 +420,10 @@ use Acme::CPANAuthors::Register (
     SHIMI     => 'Kazuhito Shimizu',
     SHINCHIT  => 'Takahiro Shinchi',
     SHINGT    => 'Shinichi Goto',
+    SHINJI    => 'shinji kakimoto',
     SHINPEI   => 'HAYASHI, Shinpei',
     SHIRAIWA  => 'Kazuma Shiraiwa',
+    SHMAEDA   => 'Shunsuke Maeda',
     SHMORIMO  => 'Shigeki Morimoto',
     SHOGO     => 'Shogo Ichinose',
     SHOHEIK   => 'Shohei Kameda',
@@ -440,6 +456,7 @@ use Acme::CPANAuthors::Register (
     SYAGI     => 'Satoshi Yagi',
     SYNCLOVER => 'Naoya Sato',
     SYOHEX    => 'Syohei Yoshida',
+    SYSCAT    => 'Makoto Sasaki',
     SYSTEMS   => 'Ken Suzuki',
     SZARATE   => 'Santiago Zarate',
     TABAYASHI => 'Tetsuya Tabayashi',
@@ -450,6 +467,7 @@ use Acme::CPANAuthors::Register (
     TAIY      => 'Taisuke Yamada',
     TAIYOH    => 'Taiyoh Tanaka',
     TAKANORI  => 'Takanori Uzuka',
+    TAKASAGO  => 'Masaaki Takasago',
     TAKASH    => 'shuhei takahashi',
     TAKASHI   => 'Takashi Saeki',
     TAKAYUKI  => 'Takayuki Ikeda',
@@ -481,6 +499,7 @@ use Acme::CPANAuthors::Register (
     TEBORA    => 'Issei Horie',
     THORIKAWA => 'Takahiro Horikawa',
     TISHIDUKA => 'Takeshi ISHIDUKA',
+    TITSUKI   => 'Itsuki Toyota',
     TKURITA   => 'Tetsuro KURITA',
     TMAESAKA  => 'Toru Maesaka',
     TMITOH    => 'Tomoaki Itoh',
@@ -503,12 +522,14 @@ use Acme::CPANAuthors::Register (
     TORU      => 'Toru Hisai',
     TOSHIFJW  => 'Toshimitsu FUJIWARA',
     TOSHIOITO => 'Toshio Ito',
+    TPLAYER   => 'Takafumi Sekiguchi',
     TRAVAIL   => 'Tomoyuki SAWA',
     TSAITO    => 'Toshiyuki Saito',
     TSUCCHI   => 'Takuya Tsuchida',
     TSUKAMOTO => 'Makio Tsukamoto',
     TSUNODA   => 'TSUNODA Kazuya',
     TURUGINA  => 'KATOU Akira',
+    TWOGMON   => 'Takaaki TSUJIMOTO',
     TXIWASAKI => 'Tooru Iwasaki',
     TYANO     => 'Tatsuhiro YANO',
     TYOSHII   => 'TakanaoYoshii',
@@ -517,6 +538,7 @@ use Acme::CPANAuthors::Register (
     UASI      => 'Tomoki Aonuma',
     UCHIKO    => 'Kousuke Uchiyama',
     UGUTOMO   => 'Tomohiro Horiuchi',
+    UINTAHORN => 'Machi Amayadori',
     UMEMOTO   => 'Hajimu Umemoto',
     UMEYUKI   => 'Hiromitsu Ito',
     UMIYOSH   => 'umiyoshi',
@@ -558,6 +580,7 @@ use Acme::CPANAuthors::Register (
     YOSIZUKA  => 'yukio kusakabe',
     YOSTY     => 'Koji Komatsu',
     YOSUKEF   => 'Yosuke Furukawa',
+    YOWCOW    => 'Yoko Oyama',
     YSAS      => 'Yasuhiro Sasama',
     YSASAKI   => 'Yoshihiro Sasaki',
     YSHIBATA  => 'Yusuke Shibata',
@@ -583,6 +606,7 @@ use Acme::CPANAuthors::Register (
     ZIGUZAGU  => 'Hiroshi Sakai',
     ZOETIN    => 'Yusuke Nozoe',
     ZONCOEN   => 'Kenta Mori',
+    ZUQQHINI  => 'Hidetomo Suzuki',
 );
 
 1;
